#
# spec file for package codelite
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2014 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1315
# Only available on x86_64 and %%arm (see lldb package)
  %ifarch %arm x86_64
    %bcond_without lldb
  %endif
# Not available on ppc
  %ifnarch ppc
    %bcond_without clang
  %endif
%endif

Name:           codelite
Version:        8.1
Release:        bp153.1.20
Summary:        Powerful open-source, cross platform code editor for C,C++,PHP and Node.js
License:        GPL-3.0
Group:          Development/Tools/IDE
# parts of package contain LGPL-3.0 licenced code thus license needs to be
# GPL-3.0
Url:            http://codelite.org/
Source0:        https://github.com/eranif/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Template files are identified by RPMLint as Development-Files --> Ignore this errors
Source1:        %{name}-rpmlintrc
# PATCH-FEATURE-OPENSUSE codelite-disable-new-version-check.patch fisiu@opensuse.org -- Disable 'new version' check on startup
Patch0:         %{name}-disable-new-version-check.patch
# TODO: Remove following patch next release
# PATCH-FIX-UPSTREAM fix-use-system-sqlite3.patch -- Use system sqlite3 version instead of projects own version. Fixed already upstream in git commit: fe554119c772d8579094b2c3315e0bab92cd4afe
Patch1:         fix-use-system-sqlite3.patch
# PATH-FIX-UPSTREAM fix-no-return-in-nonvoid-function.patch -- Fix non void function without return to avoid rpmlint error. Reported Upstream: https://github.com/eranif/codelite/issues/946
Patch2:         fix-no-return-in-nonvoid-function.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-devel >= 3.0.0
BuildRequires:  wxWidgets-devel >= 3.0.0
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(sqlite3)
%if %{with lldb}
BuildRequires:  lldb-devel
%endif
%if %{with clang}
BuildRequires:  llvm-clang-devel
%endif
Requires:       hicolor-icon-theme
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif

%description
CodeLite is a powerful open-source, cross platform code editor for the
C,C++,PHP and Node.js programming languages.
It uses a sophisticated, yet intuitive interface which allows user
easily to create, build and debug complex projects.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1

%build
%cmake \
   %if %{with clang}
  -DENABLE_CLANG=1 \
  %endif
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_INSTALL_LIBDIR=%{_lib}

make %{?_smp_mflags}

%install
%cmake_install
%find_lang %{name}
### Add mime types
mkdir -p %{buildroot}%{_datadir}/mime/packages/
cp -p %{name}.xml %{buildroot}%{_datadir}/mime/packages/
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/
ln -s %{_datadir}/%{name}/images/cubes.png %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-workspace.png
ln -s %{_datadir}/%{name}/images/cubes.png %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-project.png
%fdupes %{buildroot}%{_prefix}
### Update translation in desktop menu entry and add IDE as category
%suse_update_desktop_file %{name} IDE

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.lang
%defattr(-,root,root)
%doc about.html AUTHORS COPYING
%{_bindir}/%{name}*
%{_bindir}/clg++
%{_bindir}/clgcc
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_mandir}/man1/%{name}*.1%{ext_man}
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-workspace.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-project.png

%changelog
* Mon Mar 21 2016 mpluskal@suse.com
- Install COPYING
* Sun Oct 11 2015 mpluskal@suse.com
- Use cmake macros
- Remove conditonals for unsupported releases
- Simplify bconds and enable lldb and llvm by default on Factory
* Mon Oct  5 2015 rpm@fthiessen.de
- Update to upstream version 8.1:
  * Removed upstream merged: codelite-date-time-usage-fix.patch
  * Cleanup SPEC, new dependencies added and workarounds removed.
  * Using bundled version of .desktop, removed our codelite.desktop
  * Added fix-use-system-sqlite3.patch to use system sqlite3
    version instead of the version from codelite. Fixed already
    upstream in git commit: fe554119c772d8579094b2c3315e0bab92cd4afe
  * Added fix-no-return-in-nonvoid-function.patch to avoid RPMLint
    error, because of non void function without return.
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in postun scripts
* Tue Sep 23 2014 sfalken@opensuse.org
- Removed %%wx_requires as it is no longer a valid macro
* Tue Mar 18 2014 fisiu@opensuse.org
- Fix source tarball url.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.4:
  + New cmake plugin.
  + New tweak plugin.
  + Improved git plugin.
  + codelite-terminal: new terminal emulator.
  + Many enhancements and bug fixes.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.3:
  + Brand new SFTP plugin.
  + codelite-make: a command-line tool to generate Makefiles from codelite's
    project.
  + Improved git, database explorer, cscope and Wizard plugins.
  + Bug fixes.
* Fri Nov  8 2013 fisiu@opensuse.org
- Change previous cmake parameter to -DCMAKE_SKIP_RPATH=ON. Fix bnc#848791.
* Thu Sep 12 2013 toganm@opensuse.org
- add -DCMAKE_SKIP_INSTALL_RPATH=ON to cmake options
* Tue Jul 16 2013 fisiu@opensuse.org
- Update to 5.2:
  + Added disassemble window to the debugger
  + Better dark theme visualization
  + Improved tab appearance
  + Debugger pretty printing improvements
  + Various dialogs were re-designed (setters/getters)
  + Improved code completion
  + and much more
- Enable db explorer plugin with mariadb/mysql support.
* Wed Jun 12 2013 dvaleev@suse.com
- Add llvm-clang-devel to buildrequires, so the archs other than
  x86 would find -lclang
* Mon May 27 2013 fisiu@opensuse.org
- Change license to GPL-3.0+, fix bnc#821637.
* Thu May 16 2013 fisiu@opensuse.org
- Enable manual stripping for SLE.
* Wed May 15 2013 fisiu@opensuse.org
- Fix missing license's text in About dialog.
* Wed Apr 10 2013 fisiu@opensuse.org
- Update to 5.1:
  + Build with CMake
  + Czech translation
  + New highlight theme "Zmrok-like"
  + Improved git support
  + Code completion enhancements
  + Many bug fixes
- Patch codelite-4.1.5770-disable-autoupdate-by-default.patch was
  updated and renamed to codelite-disable-new-version-check.patch
* Fri Feb  1 2013 fisiu@opensuse.org
- Update to 5.0.6213:
  + Support for GUI RAD wxCrafter: http://wxcrafter.codelite.org
  + New plugin Zoom Navigato
  + New "New Project" dialog
  + Quick code navigation with Shift-Click (configurable)
  + Various updates to code completion
  + More bugs fixed
- Drop codelite-no-return-fix.patch: fixed upstream
- Codelite needs wxWidgets >= 2.9.4
* Tue Sep 25 2012 svalx@svalx.net
- Update to 4.1.5770:
  + "Symbol View" is now deprecated infavor of the "Outline" plugin
  + Clang code completion improvements:
  + Codelite's Makefiles are more standard (they are now using the
    standard CXX, CC, AR, CFLAGS and CXXFLAGS variables).
- Add codelite-no-return-fix.patch for fix
  no-return-in-nonvoid-function error
- Build on SLE11-SP2 whith wxGTK 2.8.8
- Add codelite-4.1.5770-disable-autoupdate-by-default.patch.
- Add some fields to desktop file.
- Changes in spec file:
  + Add MIME types for workspace and project;
  + Remove URL path from source0;
  + Use %%{__make} macros;
  + Remove duplicate GPL file from %%{_datadir};
  + Add some configure options;
  + Add %%clean section.
  + Manual strip binaries for SLE11-SP2
* Tue Jun 19 2012 fisiu@opensuse.org
- Update to 4.0.5589:
  + Enhanced support for svn, works with svn 1.7.
  + Items in debugger tooltip are editable.
  + Support for clang up to 3.2.
  + C++11 completion can be turned ON/OFF.
  + New icon set added.
  + Added CallGraph plugin.
* Sat Apr  7 2012 fisiu@opensuse.org
- Update to 3.5.5375:
  + Code completion speed improvements.
  + An improved clang code completion (with libclang).
  + New perspective management.
  + Many bug fixes.
  + Infrastructure improvements.
- Add codelite-date-time-usage-fix.patch.
* Mon Jan 24 2011 fisiu@opensuse.org
- build against wxWidgets-wxcontainer-devel instead wxGTK-devel for
  openSUSE > 11.3
* Mon Jan  3 2011 fisiu@opensuse.org
- upstream update to 2.9.0.4684:
  + Many bug fixes
  + Subversion plugin enhancements
  + Improved debugging
* Mon Nov  1 2010 fisiu@opensuse.org
- upstream update to 2.8.0.4537:
  + Many bug fixes
  + Debugger interface revamp
  + Find In Files improvements:
  - New options: ignore matches founds in comments or string
  - Color matches in comments using the editor's comment color
  + New: 'Find References'
* Wed Oct 13 2010 fisiu@opensuse.org
- upstream update to 2.7.0.4375:
  + Many bug fixes
  + New look
  + Code completion enhancements ( Macros improvement, More complex templates handling and much more )
  + New refactoring: Rename Local Variable
* Wed Jun  9 2010 fisiu@opensuse.org
- upstream update to 2.5.3.4075
  + code completion enhancements
  + many bugs were fixed
* Mon Apr 12 2010 fisiu@opensuse.org                              
- upstream update to 2.5.2.4031
  + Introducing wxAUI docking system + notebooks
  + Improvements to the debugger
  + code completion enhancements
  + Many UI changes
  + Many bugs were fixed
* Wed Mar  3 2010 fisiu@opensuse.org                              
- upstream update to 2.3.0.3833
  + Major improvements in the Code Completion
  + SymbolView plugin
  + Simplified search methods
  + Many bugs were fixed
* Tue Feb  2 2010 fisiu@opensuse.org
- upstream update to 2.2.0.3681
  + Introducing the environment variables set - define environment variable set per workspace
  + Subversion plugin - many bug fixes + improvements
  + Incremental search: Now with Replace options!
  + Improved function calltip
* Tue Jan 19 2010 fisiu@opensuse.org
- BuildRequires moved from wxWidgets to wxGTK
* Wed Dec 30 2009 fisiu@opensuse.org
- upstream update to 2.1.0.3584
* Wed Nov 18 2009 fisiu82@gmail.com
- new upstream release 2.0.3365
* Tue Oct 27 2009 fisiu82@gmail.com
- upstream update to 1.0.3035:
  + Compiler annotations and edit margin
  + New Debugger ASCII viewer
  + Better breakpoint handling
  + Get more from gdb!
  + C/C++ static code analysis by CppCheck!
  + Improved Setters / Getters dialog!
* Wed May 27 2009 fisiu82@gmail.com
- upstream update, 1.0.2841
* Mon Apr 20 2009 fisiu82@gmail.com
- upstream update, 1.0.2819
* Fri Mar  6 2009 fisiu82@gmail.com
- initial package, 1.0.2785
